@@ -43,7 +43,6 @@
 #include "infoview.h"
 #include "snprintf.h"
 #include "stream.h"
-#include "terminal.h"
 #include "textedit.h"
 #include "textfile.h"
 #include "tools.h"
@@ -2729,7 +2728,7 @@ void ht_app::handlemsg(htmsg *msg)
 			clearmsg(msg);
 			return;
 		case cmd_popup_dialog_eval: {
-			eval_dialog();
+			eval_dialog(NULL, NULL, NULL);
 			clearmsg(msg);
 			return;
 		}
